package com.zgd.dx.controller;

import com.zgd.dx.model.DxData;
import com.zgd.dx.model.dto.DxDataDto;
import com.zgd.dx.model.vo.DxDataVo;
import com.zgd.dx.service.DxDataService;
import com.zgd.dx.utils.HttpResult;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.List;

@RequestMapping("dxData")
@RestController
public class DxDataController {

    @Autowired
    private DxDataService dxDataService;


  /**
   *  @version
   *  @author: hxl
   *  @Date: 2024/9/6 16:19
   *  @Description: 通过用户id查询用户统计数据
   */
    @PostMapping("/listByUserId")
    public HttpResult<DxDataDto> listByUserId(@RequestBody DxDataVo dxDataVo) {
        DxDataDto dto =new DxDataDto();
        try{
            if(StringUtils.isBlank(dxDataVo.getUserId())){
                return HttpResult.error("用户id不能为空！！！");
            }
            dto = dxDataService.listByUserId(dxDataVo);
            dto.setExhaleDuration(dto.getExhaleDuration()==null ?"0":dto.getExhaleDuration());
            dto.setOutgoingCallsNumber(dto.getOutgoingCallsNumber()==null ?"0":dto.getOutgoingCallsNumber());
            dto.setConnectionsNumber(dto.getConnectionsNumber() ==null ?"0":dto.getConnectionsNumber());
            dto.setCallSuccessRate(dto.getCallSuccessRate()==null ?"-":dto.getCallSuccessRate());
        } catch (Exception e) {
            e.printStackTrace();
            return HttpResult.error(e.getMessage());
        }
        return HttpResult.ok(dto);
    }

   /**
    *  @version
    *  @author: hxl
    *  @Date: 2024/9/6 16:19
    *  @Description: 通过用户id 按天查询数据
    */
    @PostMapping("/listByUserIdAndDateTime")
    public HttpResult<List<DxDataDto>> listByUserIdAndDateTime(@RequestBody DxDataVo dxDataVo) {
        List<DxDataDto> list =new ArrayList<>();
        try{
            if(StringUtils.isBlank(dxDataVo.getUserId())){
                return HttpResult.error("用户id不能为空！！！");
            }
            list = dxDataService.listByUserIdAndDateTime(dxDataVo);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return HttpResult.ok(list);
    }

    /**
     *  @version
     *  @author: hxl
     *  @Date: 2024/9/6 16:19
     *  @Description: 通过用户id和日期查询用户统计数据
     */
    @PostMapping("/listByUserIdByDay")
    public HttpResult<DxDataDto> listByUserIdByDay(@RequestBody DxDataVo dxDataVo) {
        DxDataDto dto =new DxDataDto();
        try{
            if(StringUtils.isBlank(dxDataVo.getUserId())){
                return HttpResult.error("用户id不能为空！！！");
            }
            if(StringUtils.isBlank(dxDataVo.getDateTime())){
                return HttpResult.error("查询日期不能为空！！！");
            }
            dto = dxDataService.listByUserIdByDay(dxDataVo);
            dto.setDateTime(dto.getDateTime()==null?dxDataVo.getDateTime() : dto.getDateTime());
            dto.setExhaleDuration(dto.getExhaleDuration()==null ?"0":dto.getExhaleDuration());
            dto.setOutgoingCallsNumber(dto.getOutgoingCallsNumber()==null ?"0":dto.getOutgoingCallsNumber());
            dto.setConnectionsNumber(dto.getConnectionsNumber() ==null ?"0":dto.getConnectionsNumber());
            dto.setCallSuccessRate(dto.getCallSuccessRate()==null ?"-":dto.getCallSuccessRate());
        } catch (Exception e) {
            e.printStackTrace();
            return HttpResult.error(e.getMessage());
        }
        return HttpResult.ok(dto);
    }
}
