package com.zgd.dx.utils;


import java.io.Serializable;

/**
 * HTTP结果封装
 *
 * @author Louis
 * @date Jun 29, 2019
 */
public class HttpResult<T> implements Serializable {


    private int code = 200;


    private String msg;


    private T data;

    public static <T> HttpResult<T> error() {
        return error(HttpStatus.SC_INTERNAL_SERVER_ERROR, "未知异常，请联系管理员");
    }

    public static <T> HttpResult<T> error(String msg) {
        return error(HttpStatus.SC_INTERNAL_SERVER_ERROR, msg);
    }

    public static <T> HttpResult<T> error(int code, String msg) {
        HttpResult<T> r = new HttpResult<>();
        r.setCode(code);
        r.setMsg(msg);
        return r;
    }

    public static <T> HttpResult<T> error(int code, T data, String msg) {
        HttpResult<T> r = new HttpResult<>();
        r.setCode(code);
        r.setData(data);
        r.setMsg(msg);
        return r;
    }

    public static <T> HttpResult<T> error(T data) {
        HttpResult<T> r = new HttpResult<>();
        r.setCode(HttpStatus.SC_INTERNAL_SERVER_ERROR);
        r.setData(data);
        return r;
    }


    public static <T> HttpResult<T> ok(String msg) {
        HttpResult<T> r = new HttpResult<>();
        r.setMsg(msg);
        return r;
    }

    public static <T> HttpResult<T> ok(T data) {
        HttpResult<T> r = new HttpResult<>();
        r.setData(data);
        return r;
    }

    public static <T> HttpResult<T> ok(String msg, T data) {
        HttpResult<T> r = new HttpResult<>();
        r.msg = msg;
        r.setData(data);
        return r;
    }


    public static <T> HttpResult<T> ok() {
        return new HttpResult<>();
    }

    public int getCode() {
        return code;
    }

    public void setCode(int code) {
        this.code = code;
    }

    public String getMsg() {
        return msg;
    }

    public void setMsg(String msg) {
        this.msg = msg;
    }

    public T getData() {
        return data;
    }

    public void setData(T data) {
        this.data = data;
    }

    @Override
    public String toString() {
        return "HttpResult{" + "code=" + code + ", msg='" + msg + '\'' + ", data=" + data + '}';
    }

}
